pygeodesy.booleans.LatLonGH

Package pygeodesy :: Module booleans :: Class LatLonGH |
[frames] | no frames]

# Class LatLonGH

      object --+
               |
    named._Named --+
                   |
         _LatLonBool --+
                       |
                      LatLonGH

A point or intersection in a BooleanGH clip or composite.

Instance Methods
__init__(self, lat_ll, lon=None, height=0, clipid=0, **wrap_name) New `LatLonGH` from separate `lat`, `lon`, `h`eight and `clipid` scalars, or from a previous LatLonGH, ClipGH4Tuple or some other `LatLon` instance. |
isenclosedBy(self, *composites_points, **wrap) Is this point inside one or more composites or polygons based on the even-odd-rule? |
Inherited from `_LatLonBool`: `__abs__`, `__eq__`, `__ne__`, `__repr__`, `__str__`, `__sub__`, `isequalTo` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_LatLonBool`: `clipid`, `height`, `isintersection`, `ispoint`, `lat`, `latlon`, `lon` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lat_ll, lon=None, height=0, clipid=0, **wrap_name) (Constructor) |
New `LatLonGH` from separate `lat`, `lon`, `h`eight and `clipid` scalars, or from a previous LatLonGH, ClipGH4Tuple or some other `LatLon` instance. Arguments: `lat_ll` - Latitude (`scalar`) or a lat-/longitude (LatLonGH, ClipGH4Tuple or some other `LatLon`). Overrides: object.__init__ See Also: Here for further details.

### isenclosedBy (self, *composites_points, **wrap) |
Is this point inside one or more composites or polygons based on the even-odd-rule? Arguments: `composites_points` - Composites and/or iterables of points (ClipFHP4Tuple, ClipGH4Tuple, LatLonFHP, LatLonGH or any `LatLon`). `wrap` - Optional keyword argument `wrap=False`, if `True`, wrap or normalize and unroll all `points` (`bool`). Raises: `ValueError` - Some `points` invalid.